@@ -533,14 +533,14 @@ brasero_burn_dialog_get_media_type_string (BraseroBurn *burn,
 
 		if ((type & BRASERO_MEDIUM_CD) && !(type & BRASERO_MEDIUM_DVD)) {
 			if (!insert) {
-				if (isosize)
+				if (isosize > 0)
 					message = g_strdup_printf (_("Please replace the disc with a writable CD with at least %i MiB of free space."), 
 								   (int) (isosize / 1048576));
 				else
 					message = g_strdup (_("Please replace the disc with a writable CD."));
 			}
 			else {
-				if (isosize)
+				if (isosize > 0)
 					message = g_strdup_printf (_("Please insert a writable CD with at least %i MiB of free space."), 
 								   (int) (isosize / 1048576));
 				else
@@ -549,14 +549,14 @@ brasero_burn_dialog_get_media_type_string (BraseroBurn *burn,
 		}
 		else if (!(type & BRASERO_MEDIUM_CD) && (type & BRASERO_MEDIUM_DVD)) {
 			if (!insert) {
-				if (isosize)
+				if (isosize > 0)
 					message = g_strdup_printf (_("Please replace the disc with a writable DVD with at least %i MiB of free space."), 
 								   (int) (isosize / 1048576));
 				else
 					message = g_strdup (_("Please replace the disc with a writable DVD."));
 			}
 			else {
-				if (isosize)
+				if (isosize > 0)
 					message = g_strdup_printf (_("Please insert a writable DVD with at least %i MiB of free space."), 
 								   (int) (isosize / 1048576));
 				else
@@ -1039,8 +1039,10 @@ brasero_burn_dialog_eject_failure_cb (BraseroBurn *burn,
 }
 
 static BraseroBurnResult
-brasero_burn_dialog_disable_joliet_cb (BraseroBurn *burn,
-				       BraseroBurnDialog *dialog)
+brasero_burn_dialog_continue_question (BraseroBurnDialog *dialog,
+                                       const gchar *primary_message,
+                                       const gchar *secondary_message,
+                                       const gchar *button_message)
 {
 	gint result;
 	GtkWidget *button;
@@ -1050,7 +1052,7 @@ brasero_burn_dialog_disable_joliet_cb (BraseroBurn *burn,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	if (!gtk_widget_get_visible (dialog)) {
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
 	}
@@ -1060,16 +1062,18 @@ brasero_burn_dialog_disable_joliet_cb (BraseroBurn *burn,
 	message = brasero_burn_dialog_create_message (dialog,
 	                                              GTK_MESSAGE_WARNING,
 	                                              GTK_BUTTONS_NONE,
-	                                              _("Do you want to continue with full Windows compatibility disabled?"));
+	                                              primary_message);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
-						  _("Some files don't have a suitable name for a fully Windows-compatible CD."));
+						  "%s",
+	                                          secondary_message);
 
 	gtk_dialog_add_button (GTK_DIALOG (message),
-			       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+			       GTK_STOCK_CANCEL,
+	                       GTK_RESPONSE_CANCEL);
 
 	button = gtk_dialog_add_button (GTK_DIALOG (message),
-					_("_Continue"),
+					button_message,
 					GTK_RESPONSE_OK);
 	gtk_button_set_image (GTK_BUTTON (button),
 			      gtk_image_new_from_stock (GTK_STOCK_OK,
@@ -1086,7 +1090,27 @@ brasero_burn_dialog_disable_joliet_cb (BraseroBurn *burn,
 	if (result != GTK_RESPONSE_OK)
 		return BRASERO_BURN_CANCEL;
 
-	return BRASERO_BURN_OK;
+	return BRASERO_BURN_OK;	
+}
+
+static BraseroBurnResult
+brasero_burn_dialog_blank_failure_cb (BraseroBurn *burn,
+                                      BraseroBurnDialog *dialog)
+{
+	return brasero_burn_dialog_continue_question (dialog,
+	                                              _("Do you want to replace the disc and continue?"),
+	                                              _("The currently inserted disc could not be blanked."),
+	                                              _("_Replace Disc"));
+}
+
+static BraseroBurnResult
+brasero_burn_dialog_disable_joliet_cb (BraseroBurn *burn,
+				       BraseroBurnDialog *dialog)
+{
+	return brasero_burn_dialog_continue_question (dialog,
+	                                              _("Do you want to continue with full Windows compatibility disabled?"),
+	                                              _("Some files don't have a suitable name for a fully Windows-compatible CD."),
+	                                              _("C_ontinue"));
 }
 
 static void
@@ -1308,7 +1332,7 @@ brasero_burn_dialog_dummy_success_cb (BraseroBurn *burn,
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
 
-	if (!gtk_widget_get_mapped (dialog)) {
+	if (!gtk_widget_get_mapped (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
 	} else
@@ -1539,6 +1563,10 @@ brasero_burn_dialog_setup_session (BraseroBurnDialog *dialog,
 			  "insert-media",
 			  G_CALLBACK (brasero_burn_dialog_insert_disc_cb),
 			  dialog);
+	g_signal_connect (priv->burn,
+			  "blank-failure",
+			  G_CALLBACK (brasero_burn_dialog_blank_failure_cb),
+			  dialog);
 	g_signal_connect (priv->burn,
 			  "eject-failure",
 			  G_CALLBACK (brasero_burn_dialog_eject_failure_cb),
@@ -1609,6 +1637,7 @@ brasero_burn_dialog_setup_session (BraseroBurnDialog *dialog,
 static void
 brasero_burn_dialog_save_log (BraseroBurnDialog *dialog)
 {
+	GError *error;
 	gchar *contents;
 	gchar *path = NULL;
 	GtkWidget *chooser;
@@ -1650,10 +1679,17 @@ brasero_burn_dialog_save_log (BraseroBurnDialog *dialog)
 		return;
 	}
 
-	g_file_get_contents (brasero_burn_session_get_log_path (priv->session),
-			     &contents,
-			     NULL,
-			     NULL);
+	error = NULL;
+	if (!g_file_get_contents (brasero_burn_session_get_log_path (priv->session),
+	                          &contents,
+	                          NULL,
+	                          &error)) {
+		g_warning ("Error while saving log file: %s\n", error? error->message:"none");
+		g_error_free (error);
+		g_free (path);
+		return;
+	}
+	
 	g_file_set_contents (path, contents, -1, NULL);
 
 	g_free (contents);
@@ -1828,7 +1864,7 @@ brasero_burn_dialog_notify_copy_finished (BraseroBurnDialog *dialog,
 
 	brasero_burn_dialog_update_session_info (dialog);
 
-	if (!gtk_widget_get_visible (dialog))
+	if (!gtk_widget_get_visible (GTK_WIDGET (dialog)))
 		gtk_widget_show (GTK_WIDGET (dialog));
 
 	main_message = g_strdup_printf (_("Copy #%i has been burned successfully."), priv->num_copies ++);
@@ -2540,7 +2576,7 @@ brasero_burn_dialog_init (BraseroBurnDialog * obj)
 	alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
 	gtk_widget_show (alignment);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 6, 8, 6, 6);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (obj)->vbox),
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (obj))),
 			    alignment,
 			    TRUE,
 			    TRUE,
