@@ -44,11 +44,11 @@ G_BEGIN_DECLS
 #define LIBBRASERO_MEDIA_VERSION_MINOR						\
 	31
 #define LIBBRASERO_MEDIA_VERSION_MICRO						\
-	90
+	92
 #define LIBBRASERO_MEDIA_AGE							\
 	302
 #define LIBBRASERO_MEDIA_INSTALL							\
-	"/scratch/jhbuild"
+	"/usr/local"
 
 /**
  * To start and stop the library
