@@ -525,7 +525,7 @@ brasero_genisoimage_export_caps (BraseroPlugin *plugin)
 
 	brasero_plugin_define (plugin,
 			       "genisoimage",
-	                       /* Translators: image is a disc image here */
+	                       NULL,
 			       _("Creates disc images from a file selection"),
 			       "Philippe Rouquier",
 			       1);
